const express = require('express');

const portalMecSchoolName = express.Router();

const libs = `${process.cwd()}/libs`;

const log = require(`${libs}/log`)(module);

const squel = require('squel');

const query = require(`${libs}/middlewares/query`).query;

const response = require(`${libs}/middlewares/response`);

const id2str = require(`${libs}/middlewares/id2str`);

const ReqQueryFields = require(`${libs}/middlewares/reqQueryFields`);

const request = require(`request`);

const config = require(`${libs}/config`);

const passport = require('passport');

const download = require(`${libs}/middlewares/downloadDatabase`);

const addMissing = require(`${libs}/middlewares/addMissing`);

const cache = require('apicache').options({ debug: config.debug, statusCodes: {include: [200]} }).middleware;

let rqf = new ReqQueryFields();

// Return location
portalMecSchoolName.get('/year_range', cache('15 day'), (req, res, next) => {
    req.sql.from('escola')
    .field('MIN(escola.ano_censo)', 'start_year')
    .field('MAX(escola.ano_censo)', 'end_year');
    next();
}, query, response('range'));

portalMecSchoolName.get('/years', cache('15 day'), (req, res, next) => {
    req.sql.from('escola').
    field('DISTINCT escola.ano_censo', 'year');
    next();
}, query, response('years'));

portalMecSchoolName.get('/source', (req, res, next) => {
    req.sql.from('fonte')
    .field('fonte', 'source')
    .where('tabela = \'escola\'');
    next();
}, query, response('source'));

rqf.addField({
    name: 'filter',
    field: false,
    where: true
}).addValue({
    name: 'city',
    table: 'municipio',
    tableField: 'nome',
    resultField: 'city_name',
    where: {
        relation: 'LIKE',
        type: 'string',
        field: 'nome',
        table: 'municipio'
    },
    join: {
        primary: 'id',
        foreign: 'municipio_id',
        foreignTable: 'escola'
    }
}).addValue({
    name: 'state',
    table: 'estado',
    tableField: 'sigla',
    resultField: 'state_name',
    where: {
        relation: 'LIKE',
        type: 'string',
        field: 'sigla',
        table: 'estado'
    },
    join: {
        primary: 'id',
        foreign: 'estado_id',
        foreignTable: 'escola'
    }
});

portalMecSchoolName.get('/', rqf.parse(), rqf.build(), (req, res, next) => {
  if(("state" in req.filter) && ("city" in req.filter)) {
    console.log(req.filter);
    req.sql.from('escola')
        .field('DISTINCT escola.id')
        .field('escola.nome_escola', 'name')
        .join('municipio', null, 'municipio.id=escola.municipio_id')
        .field('municipio.nome', 'city_name')
        .join('estado', null, 'estado.id=escola.estado_id')
        .field('estado.sigla', 'state_name')
        delete req.filter.state;
        delete req.filter.city;
        next();
  }
  else {
    res.status(400);
    next({
      status: 400,
      message: 'Wrong/No filter specified'
    });
  }
}, query, response('portalMec_schoolName'));

module.exports = portalMecSchoolName;
